@@ -17,7 +17,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software Foundation,
+// along with Pierogi; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 
@@ -151,6 +151,9 @@ MainWindow::MainWindow(QWidget *parent)
   // Set up the select keyset form:
   selectKeysetForm->selectKeyset(currentKeyset);
 
+  // Inform the favorites dialog of this keyset:
+  favoritesDialog->initialKeyset(currentKeyset);
+
   // Select the panel types:
   currentPanelTypes = myKeysets->getPanelTypes(currentKeyset);
 
