@@ -40,11 +40,13 @@ extern bool commandInFlight;
 PIRKeysetMetaData::PIRKeysetMetaData(
   const char *r,
   PIRMakeName m,
+  PIRPanelTypes p,
   unsigned int i)
   : threadableProtocol(NULL),
     index(i),
     keysetName(r),
-    make(m)
+    make(m),
+    panelTypes(p)
 {
 }
 
@@ -114,6 +116,12 @@ const char *PIRKeysetMetaData::getKeysetName() const
 }
 
 
+PIRPanelTypes PIRKeysetMetaData::getPanelTypes() const
+{
+  return panelTypes;
+}
+
+
 unsigned int PIRKeysetMetaData::getCarrierFrequency() const
 {
   if (!threadableProtocol)
